@@ -236,36 +236,44 @@ class MediumGetEventFiltersTest(TestCase):
             G(Event, context={}, time_expires=datetime(2014, 1, 17))
         G(EventSeen, event=e1, medium=self.medium)
 
+        self.actor = G(Entity)
+        G(EventActor, event=e1, entity=self.actor)
+
     def test_start_time(self):
-        filters = self.medium.get_event_filters(datetime(2014, 1, 16), None, None, True)
+        filters = self.medium.get_filtered_events_queries(datetime(2014, 1, 16), None, None, True, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 3)
 
     def test_end_time(self):
-        filters = self.medium.get_event_filters(None, datetime(2014, 1, 16), None, True)
+        filters = self.medium.get_filtered_events_queries(None, datetime(2014, 1, 16), None, True, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 2)
 
     def test_is_seen(self):
-        filters = self.medium.get_event_filters(None, None, True, True)
+        filters = self.medium.get_filtered_events_queries(None, None, True, True, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 1)
 
     def test_is_not_seen(self):
-        filters = self.medium.get_event_filters(None, None, False, True)
+        filters = self.medium.get_filtered_events_queries(None, None, False, True, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 4)
 
     def test_include_expires(self):
-        filters = self.medium.get_event_filters(None, None, None, True)
+        filters = self.medium.get_filtered_events_queries(None, None, None, True, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 5)
 
     def test_dont_include_expires(self):
-        filters = self.medium.get_event_filters(None, None, None, False)
+        filters = self.medium.get_filtered_events_queries(None, None, None, False, None)
         events = Event.objects.filter(*filters)
         self.assertEqual(events.count(), 4)
 
+    def test_actor(self):
+        filters = self.medium.get_filtered_events_queries(None, None, None, True, self.actor)
+        events = Event.objects.filter(*filters)
+        self.assertEqual(events.count(), 1)
+
 
 class MediumFollowedByTest(TestCase):
     def setUp(self):
